Changelog
=========

0.2 - 2013-02-19
----------------

- Keep constistent with plone's email login #12187, so don't lowercase email
  addresses.
  [saily]

- Add basic membrane group behavior
  [saily]


0.1 - 2012-09-20
----------------

- Initial alpha release
